@@ -1,6 +1,6 @@
 /*
  * macports.c
- * $Id: macports.c 58126 2009-09-22 17:29:57Z jmr@macports.org $
+ * $Id: macports.c 134513 2015-03-27 21:27:54Z cal@macports.org $
  *
  * Copyright (c) 2009 The MacPorts Project
  * Copyright (c) 2003 Apple Inc.
@@ -38,28 +38,14 @@
 #include <tcl.h>
 
 #include "get_systemconfiguration_proxies.h"
-#include "realpath.h"
 #include "sysctl.h"
 
-static int
-macports__version(ClientData clientData UNUSED, Tcl_Interp *interp, int objc, Tcl_Obj * CONST objv[])
-{
-	if (objc != 1) {
-		Tcl_WrongNumArgs(interp, 1, objv, NULL);
-		return TCL_ERROR;
-	}
-	Tcl_SetObjResult(interp, Tcl_GetVar2Ex(interp, "macports::autoconf::macports_version", NULL, 0));
-	return TCL_OK;
-}
-
 int
 Macports_Init(Tcl_Interp *interp)
 {
 	if (Tcl_InitStubs(interp, "8.4", 0) == NULL)
 		return TCL_ERROR;
-	Tcl_CreateObjCommand(interp, "macports::version", macports__version, NULL, NULL);
 	Tcl_CreateObjCommand(interp, "get_systemconfiguration_proxies", GetSystemConfigurationProxiesCmd, NULL, NULL);
-	Tcl_CreateObjCommand(interp, "realpath", RealpathCmd, NULL, NULL);
 	Tcl_CreateObjCommand(interp, "sysctl", SysctlCmd, NULL, NULL);
 	if (Tcl_PkgProvide(interp, "macports", "1.0") != TCL_OK)
 		return TCL_ERROR;
