@@ -1,6 +1,6 @@
 /*
  * Pextlib.c
- * $Id: Pextlib.c 112418 2013-10-22 13:23:02Z jmr@macports.org $
+ * $Id: Pextlib.c 135852 2015-05-05 17:36:35Z cal@macports.org $
  *
  * Copyright (c) 2002 - 2003 Apple Inc.
  * Copyright (c) 2004 - 2005 Paul Guyot <pguyot@kallisys.net>
@@ -33,10 +33,17 @@
  * POSSIBILITY OF SUCH DAMAGE.
  */
 
-#if HAVE_CONFIG_H
+#ifdef HAVE_CONFIG_H
 #include <config.h>
 #endif
 
+/* required for strdup(3) on Linux and OS X */
+#define _XOPEN_SOURCE 600L
+/* required for clearenv(3)/setenv(3)/unsetenv(3) on Linux */
+#define _BSD_SOURCE
+/* required for clearenv(3)/setenv(3)/unsetenv(3) on OS X */
+#define _DARWIN_C_SOURCE
+
 #include <sys/types.h>
 #include <sys/socket.h>
 #include <sys/stat.h>
@@ -94,7 +101,7 @@
 extern char **environ;
 #endif
 
-#if !HAVE_SETMODE
+#ifndef HAVE_SETMODE
 #include "setmode.h"
 #endif
 
@@ -203,13 +210,13 @@ int ExistsuserCmd(ClientData clientData UNUSED, Tcl_Interp *interp, int objc, Tc
 
     user = strdup(Tcl_GetString(objv[1]));
     if (isdigit(*(user)))
-        pwent = getpwuid(strtol(user, 0, 0));
+        pwent = getpwuid((uid_t)strtol(user, 0, 0));
     else
         pwent = getpwnam(user);
     free(user);
 
     if (pwent == NULL)
-        tcl_result = Tcl_NewIntObj(0);
+        tcl_result = Tcl_NewIntObj(-1);
     else
         tcl_result = Tcl_NewIntObj(pwent->pw_uid);
 
@@ -230,13 +237,13 @@ int ExistsgroupCmd(ClientData clientData UNUSED, Tcl_Interp *interp, int objc, T
 
     group = strdup(Tcl_GetString(objv[1]));
     if (isdigit(*(group)))
-        grent = getgrgid(strtol(group, 0, 0));
+        grent = getgrgid((gid_t)strtol(group, 0, 0));
     else
         grent = getgrnam(group);
     free(group);
 
     if (grent == NULL)
-        tcl_result = Tcl_NewIntObj(0);
+        tcl_result = Tcl_NewIntObj(-1);
     else
         tcl_result = Tcl_NewIntObj(grent->gr_gid);
 
@@ -254,7 +261,7 @@ int NextuidCmd(ClientData clientData UNUSED, Tcl_Interp *interp, int objc UNUSED
 
     cur = MIN_USABLE_UID;
 
-    while (getpwuid(cur) != NULL) {
+    while (getpwuid((uid_t)cur) != NULL) {
         cur++;
     }
 
@@ -271,7 +278,7 @@ int NextgidCmd(ClientData clientData UNUSED, Tcl_Interp *interp, int objc UNUSED
 
     cur = MIN_USABLE_GID;
 
-    while (getgrgid(cur) != NULL) {
+    while (getgrgid((gid_t)cur) != NULL) {
         cur++;
     }
 
@@ -361,13 +368,6 @@ int CreateSymlinkCmd(ClientData clientData UNUSED, Tcl_Interp *interp, int objc,
 int UnsetEnvCmd(ClientData clientData UNUSED, Tcl_Interp *interp, int objc, Tcl_Obj *CONST objv[])
 {
     char *name;
-    char **envp;
-    char *equals;
-    size_t len;
-    Tcl_Obj *tclList;
-    int listLength;
-    Tcl_Obj **listArray;
-    int loopCounter;
 
     if (objc != 2) {
         Tcl_WrongNumArgs(interp, 1, objv, "name");
@@ -386,18 +386,21 @@ int UnsetEnvCmd(ClientData clientData UNUSED, Tcl_Interp *interp, int objc, Tcl_
            clearenv() but that is not yet standardized, instead use Tcl's
            list capability to easily build an array of strings for each
            env name, then loop through that list to unsetenv() each one */
-        tclList = Tcl_NewListObj( 0, NULL );
+        Tcl_Obj *tclList = Tcl_NewListObj( 0, NULL );
         Tcl_IncrRefCount( tclList );
         /* unset all current environment variables */
-        for (envp = environ; *envp != NULL; envp++) {
-            equals = strchr(*envp, '=');
+        for (char **envp = environ; *envp != NULL; envp++) {
+            char *equals = strchr(*envp, '=');
             if (equals != NULL) {
-                len = equals - *envp;
+				size_t len = (size_t)(equals - *envp);
                 Tcl_ListObjAppendElement(interp, tclList, Tcl_NewStringObj(*envp, len));
             }
         }
+
+		int listLength;
+		Tcl_Obj **listArray;
         Tcl_ListObjGetElements(interp, tclList, &listLength, &listArray);
-        for (loopCounter = 0; loopCounter < listLength; loopCounter++) {
+        for (int loopCounter = 0; loopCounter < listLength; loopCounter++) {
             unsetenv(Tcl_GetString(listArray[loopCounter]));
         }
         Tcl_DecrRefCount( tclList );
