@@ -1,6 +1,6 @@
 # et:ts=4
 # portload.tcl
-# $Id: portload.tcl 103400 2013-02-24 20:49:40Z cal@macports.org $
+# $Id: portload.tcl 116449 2014-01-25 16:57:17Z cal@macports.org $
 #
 # Copyright (c) 2007, 2009, 2011 The MacPorts Project
 # Copyright (c) 2007 James D. Berry
@@ -53,7 +53,7 @@ proc portload::load_main {args} {
     set launchctl_path ${portutil::autoconf::launchctl_path}
 
     foreach { path } "/Library/${startupitem.location}/${startupitem.plist}" {
-        if {[string length $launchctl_path] == 0} {
+        if {$launchctl_path eq ""} {
             return -code error [format [msgcat::mc "launchctl command was not found by configure"]]
         } elseif {![file exists $path]} {
             return -code error [format [msgcat::mc "Launchd plist %s was not found"] $path]
